

set -ex



./run_qt_test.sh
test -d $PREFIX/include/qt6/QtWebChannel
test -f $PREFIX/lib/libQt6WebChannel${SHLIB_EXT}
test -d $PREFIX/include/qt6/QtWebChannelQuick
test -f $PREFIX/lib/libQt6WebChannelQuick${SHLIB_EXT}
exit 0
